#!/bin/bash
# GTK+ utility for editing MP2, MP3, MP4, FLAC, Ogg and other media tags
# 
# http://easytag.sourceforge.net
#
# script by : til <rob DOT til DOT freedman AT googlemail DOT com>
#
set -e -x -u

# easytag
version='2.1.6'
build='64.1'

arch=${arch:-i686}
tune=pentium-m
tune=${tune:-i686}

REPO="http://zenwalk.pinguix.com/user-accounts/tilderb/extra/xap/easytag"

PKG_DEP="atk,cairo,expat,flac,fontconfig,freetype,gcc,gcc-g++,glib2,gtk+2,id3lib,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,libid3tag,libmp4v2,libogg,libpng,libvorbis,libxcb,pango,pixman,speex,wavpack,zlib"
PKG_SRC="http://downloads.sourceforge.net/easytag/easytag-$version.tar.bz2
$REPO/build-easytag.sh"

pkgname=easytag-$version
package=easytag-$version-$arch-$build

# keep care of used patches
patches=
function patcher() 
{ patch ${1} < $CWD/${2} || kill $$
  cp $CWD/${2} $PKG/usr/src/$pkgname
  patches+="${2} "
}

# build root
CWD=`pwd`
TMP=${TMP:-$CWD/tmp}
PKG=$TMP/$package
SRC=$TMP/$pkgname

[ -d $SRC ] && rm -fr $SRC
[ -d $PKG ] && rm -fr $PKG

mkdir -p $SRC $PKG/{install,/usr/{doc,src}/$pkgname}

# Extract the source archive
tar xf $CWD/$pkgname.tar.bz2 --strip-components=1 -C $SRC
cd $SRC

patcher -p1 easytag-2.1.6-cddb.patch
patcher -p1 easytag-2.1.6-new_libmp4v2.patch
patcher -p1 easytag-2.1.6-desktop.patch
patcher -p1 easytag-2.1.6-gcc43.patch

# ./configure --help >$CWD/configure--help
CFLAGS="-O2 -march=$arch -mtune=$tune " \
CXXFLAGS="-O2 -march=$arch -mtune=$tune " \
  ./configure \
   --prefix=/usr \
   --mandir=/usr/man \

make || exit 1
make install DESTDIR=$PKG

# helperline
(cd $PKG;find . -printf "%y %M %u:%g %p %l\n") >$CWD/make.install

# docs
cp -a COPYING ChangeLog TODO README THANKS \
   doc/vorbis doc/id3 doc/users_guide* doc/*.html $PKG/usr/doc/$pkgname

cd $PKG
# make icons from xpm logo
for size in 16x16 24x24 32x32 48x48; do
  mkdir -p  usr/share/icons/hicolor/${size}/apps
  convert -resize $size -depth 8 usr/share/pixmaps/EasyTAG_icon.xpm \
   			usr/share/icons/hicolor/${size}/apps/easytag.png
done
# strip symbols
strip --strip-unneeded usr/bin/easytag

# zip man page
gzip -9 usr/man/man1/easytag.1

# set ownership and permissions
find usr/doc  -type f -exec chmod 644 {} \;

# create the slack-desc
#      |----handy-ruler------------------------------------------------------|
cat <<EOF > install/slack-desc
easytag: EasyTAG (media tag editor MP2, MP3, MP4, FLAC, Ogg and others)
easytag:
easytag: EasyTAG is a GTK+ utility for viewing and editing tags for
easytag: MP3, MP2, FLAC, Ogg Vorbis, MusePack (.mpc), MP4/aac, ogg/speex
easytag: and Monkey's Audio files (.ape).
easytag:
easytag:
EOF

# don't needed any more and misplaced
rm -fr usr/share/pixmaps

# surplus files
#rm -fr usr/share/locate usr/doc/easytag-2.1.6/{EasyTAG_Documentation_sv.html,EasyTAG_Documentation_fr.html,users_guide_french}

# avoid duplicates
( cd usr/share/easytag; rm ChangeLog; ln -s ../../doc/$pkgname/ChangeLog ChangeLog )

# copy build script
cp $CWD/build-easytag.sh usr/src/$pkgname

# finalize
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

# meta info files
cd $CWD
#depfinder $PKG > $package.dep
echo -n $PKG_DEP > $package.dep
echo "$PKG_SRC" > $package.src
for pt in $patches;
 do echo "$REPO/$pt" >> $package.src;
done
md5sum $package.txz >$package.md5

